CREATE TABLE IF NOT EXISTS 'configurationdevice'(
	'configurationid' INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	'locale' TEXT,
	'themename' TEXT,
	'themecolour' INTEGER DEFAULT 0, 
	'copylibraryonsync' INTEGER,
	'enablehistoriccontent' INTEGER DEFAULT 0,
	'historicx' INTEGER DEFAULT 0,
	'historicy' INTEGER DEFAULT 0,
	'useposition' INTEGER DEFAULT 0,
	'historictime' TEXT,
	'submitstatistics' INTEGER DEFAULT 1,
	'version' TEXT,
	'nextsessionforce' INTEGER DEFAULT 0,
	'countrycode' TEXT,
	'ip' TEXT,
	'installdate' INTEGER DEFAULT 0);
	
CREATE TABLE IF NOT EXISTS 'Devices'(
	'id' INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	'deviceid' TEXT,
	'deviceidtype' INTEGER DEFAULT 0,
	'devicename' TEXT, 
	'appdeviceid' TEXT DEFAULT NULL,
	'pendingdeviceid' TEXT DEFAULT NULL,
	'replacementdevicestatus' INTEGER DEFAULT 0,
	'deviceprehash' TEXT,
	'isvm' INTEGER DEFAULT 0,
	'ismaster' INTEGER DEFAULT 1,
	'accountsprehashpending' TEXT DEFAULT NULL,
	'accountsprehash' TEXT DEFAULT NULL,
	'accountshash' TEXT,
	'accountshashpending' TEXT
);
	
CREATE TABLE IF NOT EXISTS "Resources"(
	"name" TEXT NOT NULL,
	"timestamp" INTEGER DEFAULT 0,
	"type" INTEGER NOT NULL,
	UNIQUE("name") ON CONFLICT REPLACE);
	
CREATE TABLE IF NOT EXISTS "ScheduleSettings"(
	"schedulesettingsid" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"minimiseonstartup" TEXT NOT NULL,
	"autosynconstartup" TEXT NOT NULL,
	"openonsync" TEXT NOT NULL,
	"notifyme" TEXT NOT NULL,
	"lastschedulebackup" TEXT NOT NULL,
	"status" TEXT NOT NULL,
	"showpopularactivities" INTEGER DEFAULT 1,
	"afterfirstsynconday" INTEGER DEFAULT 1,
	'dateset' INTEGER DEFAULT 0);

CREATE TABLE IF NOT EXISTS "SchedulerRules"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, 
	"typeId" INTEGER NOT NULL, 
	"date" TEXT);
	
INSERT INTO SchedulerRules (typeId, date) VALUES (2, '32400000');
INSERT INTO SchedulerRules (typeId, date) VALUES (3, '32400000|61200000');
INSERT INTO SchedulerRules (typeId, date) VALUES (4, '0');
INSERT INTO SchedulerRules (typeId, date) VALUES (5, '7|32400000');

CREATE TABLE IF NOT EXISTS "SchedulerTypes"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, 
	"ref" TEXT NOT NULL, 
	"max_rules" INTEGER NOT NULL DEFAULT 5);

INSERT INTO SchedulerTypes (ref, max_rules) VALUES ('weekly', 5);
INSERT INTO SchedulerTypes (ref, max_rules) VALUES ('daily', 5);
INSERT INTO SchedulerTypes (ref, max_rules) VALUES ('hourly', 1);
INSERT INTO SchedulerTypes (ref, max_rules) VALUES ('manually', 0);
INSERT INTO SchedulerTypes (ref, max_rules) VALUES ('everyn', 1);

CREATE TABLE IF NOT EXISTS "SchedulerSelection"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, 
	"ruleId" INTEGER NOT NULL,
	'userset' INTEGER DEFAULT 1);
	
CREATE TABLE IF NOT EXISTS "jsonlog" (
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"version" INTEGER DEFAULT 0, 
	"revision_major" INTEGER NOT NULL, 
	"revision_minor" INTEGER NOT NULL, 
	"deviceid" TEXT, 
	"jsontime" INTEGER NOT NULL, 
	"operationtime" INTEGER NOT NULL, 
	"operationtype" INTEGER NOT NULL,
	"releasetype" INTEGER NOT NULL,
	"filenumber" INTEGER DEFAULT 0,
	"totalfiles" INTEGER NOT NULL,
	"operationstatus" INTEGER DEFAULT 0, 
	UNIQUE("version", "revision_major", "revision_minor", "deviceid", "operationtype", "totalfiles", "filenumber") ON CONFLICT REPLACE);
	
CREATE TABLE IF NOT EXISTS "DiaryViewFilter"(
	"diaryviewfilterid" INTEGER PRIMARY KEY AUTOINCREMENT,
	"service" TEXT NOT NULL,
	"userid" TEXT NOT NULL,
	"selected" TEXT);
	
CREATE TABLE IF NOT EXISTS "SyncOption"(
	"ConfigurationId" INTEGER PRIMARY KEY AUTOINCREMENT,
	"name" TEXT,
	"value" TEXT,
	"type" TEXT,
	"isFreeOption" TEXT,
	"service" INTEGER,
	"userid" TEXT);
	
CREATE TABLE IF NOT EXISTS "DatabaseUpdate"(
	"patch" TEXT PRIMARY KEY,
	"updatetime" TEXT NOT NULL,
	"version" TEXT NOT NULL,
	"build" TEXT DEFAULT -1);
	
CREATE TABLE IF NOT EXISTS "ServerMessage"(
	"id" TEXT PRIMARY KEY,
	"text" TEXT,
	"type" TEXT,
	"created" TEXT,
	"expiry" TEXT,
	"count" INTEGER);
	
CREATE TABLE IF NOT EXISTS "PasswordProtection"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"hint" TEXT,
	"inactivitycount" INTEGER,
	"lockinactivity" TEXT,
	"locksleeping" TEXT,
	"md5" TEXT,
	"md5New" TEXT,
	"passwordtype" INTEGER DEFAULT 0,
	"failedPasswordCount" INTEGER,
	"resetPasswordTime" FLOAT,
	"failedAnswerCount" INTEGER,
	"resetAnswerTime" FLOAT,
	"passwordDeviceID" TEXT,
	"lastUpdatedDate" FLOAT,
	"autofillpass" INTEGER DEFAULT 0,
	"passwordversion" INTEGER DEFAULT 1);
	
INSERT INTO PasswordProtection (inactivitycount, lockinactivity, locksleeping, failedPasswordCount, resetPasswordTime, failedAnswerCount, resetAnswerTime) VALUES (10, 'false', 'false', 0, 0, 0, 0);

CREATE TABLE IF NOT EXISTS "PendingAction"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"actionType" INTEGER DEFAULT 0,
	"value" TEXT NOT NULL,
	"valueType" INTEGER DEFAULT 0,
	"session" TEXT,
	UNIQUE("actionType", "value", "valueType") ON CONFLICT IGNORE);
	
CREATE TABLE IF NOT EXISTS "newfeatures" (
	"id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"feature" TEXT NOT NULL, 
	"version" TEXT NOT NULL, 
	"dateseen" TEXT, 
	"hasseen" INT NOT NULL DEFAULT 0);

CREATE TABLE IF NOT EXISTS "configurationlibrary"(
	"configurationid" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"isfirsttime" INTEGER,
	"label" INTEGER DEFAULT 0,
	"copylibrarystatus" INTEGER DEFAULT 0,
	"libraryshared" INTEGER DEFAULT 0,
	"licencecode" TEXT,
	"originatingwl" INTEGER DEFAULT 0);

CREATE TABLE IF NOT EXISTS "patches"(
	"userid" TEXT NOT NULL,
	"type" TEXT NOT NULL,
	"executed" TEXT NOT NULL,
	"timestamp" TEXT,
	"version" TEXT,
	PRIMARY KEY ("userid","type") ON CONFLICT IGNORE);

CREATE TABLE IF NOT EXISTS "_librarySettings"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT,
	"baseid" TEXT DEFAULT '',
	"deviceid" TEXT NOT NULL,
	"deviceidtype" INTEGER DEFAULT 0,
	"key" TEXT NOT NULL
);

CREATE TABLE IF NOT EXISTS "_jfsrevision"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT,
	"revision" INTEGER DEFAULT 0,
	"version" INTEGER DEFAULT 0,
	"startdate" INTEGER DEFAULT 0,
	"enddate" INTEGER DEFAULT 0,
	"totalfiles" INTEGER DEFAULT 0,
	UNIQUE("revision") ON CONFLICT IGNORE
);

CREATE TABLE IF NOT EXISTS "_jfsrevisionfile"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT,
	"revision" TEXT,
	"name" TEXT,
	UNIQUE("revision", "name") ON CONFLICT IGNORE
);

CREATE TABLE IF NOT EXISTS "_property"(
	"id" INTEGER PRIMARY KEY AUTOINCREMENT,
	"key" INTEGER,
	"valuetype" INTEGER,
	"intvalue" INTEGER DEFAULT 0,
	"charvalue" TEXT DEFAULT NULL,
	UNIQUE("key") ON CONFLICT REPLACE
);

CREATE TABLE IF NOT EXISTS "_licence"(
	"LicenceId" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	"key" TEXT,
	"supersededkey" TEXT DEFAULT "",
	"firstname" TEXT,
	"lastname" TEXT,
	"email" TEXT,
	"signature" TEXT,
	"status" TEXT,
	"errorcode" TEXT,
	"errormessage" TEXT,
	"licencetype" TEXT,
	"producttype" TEXT,
	"expirydate" TEXT,
	"accountdeletesattempted" INTEGER DEFAULT 0,
	"accountdeletesallowed" INTEGER DEFAULT 0,
	"paid" INTEGER,
	"lastcheckdate" INTEGER DEFAULT 0,
	"ceaseusagedate" INTEGER DEFAULT 0,
	"createddate" TEXT,
	"isshared" INTEGER DEFAULT 0,
	"libraryinstallcount" INTEGER DEFAULT 0,
	"remotelogging" INTEGER DEFAULT 0,
	"partnerid" TEXT
);